///File : LetterGameBase.hpp
//------------------------------------------------------------------------------
/*
    This file is part of LetterGames.

    LetterGames is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LetterGames is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LetterGames.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif
//------------------------------------------------------------------------------
#include <wx/textfile.h>
//------------------------------------------------------------------------------
#include <vector>
//------------------------------------------------------------------------------
#include <stdlib.h>
#include <time.h>
//------------------------------------------------------------------------------
#include "config.hpp"
#include "findFile.hpp"
//------------------------------------------------------------------------------

#if not defined LETTER_GAMES_BASE_HPP_LETTER_GAMES
#define LETTER_GAMES_BASE_HPP_LETTER_GAMES
//------------------------------------------------------------------------------
struct StructAvailableLanguages
{
    wxString realName;
    wxString name;
};
//------------------------------------------------------------------------------

class LetterGameBase
{
public:
    LetterGameBase();
    void Init(const wxString &defaultLanguage);

    void LoadWords(const wxString &language);

    bool IsLanguageAvailable(const wxString &language) const;
    wxString GetLanguageRealName(const wxString &language) const;
    wxString GetLanguageName(const wxString &language) const;
    wxArrayString GetLanguageRealNameList() const;
    wxString GetCurrentLanguage() const;

    int GetWordListCount() const;

    wxString GetLettersFor(const wxChar &letter) const;
    wxString GetEveryUserLetter() const; // Return the letter that the user can try...

    int Hasard(int min, int max) const;

    bool IsOk() const;

protected:
    std::vector<wxString> m_wordsTbl;
    std::vector<StructAvailableLanguages> m_availableLanguagesList;

    int m_LongestWordLen;

    bool m_isOk;
    wxString m_defaultLanguage, m_currentLanguage;

};

#endif //LETTER_GAMES_BASE_HPP_LETTER_GAMES
